Welcome to geoip2-tools's documentation!
======================================
Automatic updates and administration of MaxMind GeoIP2 databases.

To **install** geoip2-tools, run this command in your terminal:

.. code-block:: console

    $ pip install amazon_dash


Contents
--------

.. toctree::
   :maxdepth: 3

   readme
   installation
   usage
   troubleshooting
   modules
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
